djinfo
======

.. image:: https://gitlab.com/h3/djinfo/badges/master/build.svg
    :target: https://gitlab.com/h3/djinfo/pipelines

.. image:: https://readthedocs.org/projects/djinfo/badge/?version=latest
    :target: https://djinfo.readthedocs.io/en/latest/?badge=latest

Debugging information page intented for production use.

.. figure:: docs/topics/img/djinfo-screenshot.png
    :alt: Screenshot
    :align: center
    :width: 1003px
